@@ -3,15 +3,11 @@ import importlib
 import inspect
 import os
 import platform
-import shutil
-import sys
+import subprocess
 from abc import ABC, abstractmethod
-from cgi import parse_header
 from pathlib import Path
-from urllib.parse import urlparse
 
-import requests
-from cookiecutter.main import cookiecutter
+from cookiecutter import exceptions as cookiecutter_exceptions
 from cookiecutter.repository import is_repo_url
 from platformdirs import PlatformDirs
 
@@ -20,30 +16,31 @@ try:
 except ModuleNotFoundError:
     import tomli as tomllib
 
-from briefcase import __version__, integrations
+from briefcase import __version__
 from briefcase.config import AppConfig, BaseConfig, GlobalConfig, parse_config
 from briefcase.console import Console, Log
 from briefcase.exceptions import (
-    BadNetworkResourceError,
     BriefcaseCommandError,
     BriefcaseConfigError,
     InfoHelpText,
-    MissingNetworkResourceError,
+    NetworkFailure,
 )
-from briefcase.integrations.subprocess import Subprocess
+from briefcase.integrations.base import ToolCache
+
+
+class InvalidTemplateRepository(BriefcaseCommandError):
+    def __init__(self, template):
+        self.template = template
+        super().__init__(
+            f"Unable to clone application template; is the template path {template!r} correct?"
+        )
 
 
 class TemplateUnsupportedVersion(BriefcaseCommandError):
-    def __init__(self, python_version_tag):
-        self.python_version_tag = python_version_tag
+    def __init__(self, briefcase_version):
+        self.briefcase_version = briefcase_version
         super().__init__(
-            f"""\
-Could not find template for Python {self.python_version_tag}.
-
-This is likely because Python {self.python_version_tag} is not yet supported. You will need to:
-  * Use an older version of Python; or
-  * Define your own custom template.
-"""
+            f"Could not find a template branch for Briefcase {briefcase_version}."
         )
 
 
@@ -116,90 +113,49 @@ class BaseCommand(ABC):
 
     def __init__(
         self,
-        base_path,
-        home_path=None,
-        data_path=None,
-        apps=None,
-        input_enabled=True,
+        logger: Log,
+        console: Console,
+        tools: ToolCache = None,
+        apps: dict = None,
+        base_path: Path = None,
+        data_path: Path = None,
+        is_clone: bool = False,
     ):
-        # Some details about the host machine
-        self.host_arch = platform.machine()
-        self.host_os = platform.system()
+        """Base for all Commands.
 
-        self.base_path = Path(base_path)
+        :param logger: Logger for console and logfile.
+        :param console: Facilitates console interaction and input solicitation.
+        :param tools: Cache of tools populated by Commands as they are required.
+        :param apps: Dictionary of project's Apps keyed by app name.
+        :param base_path: Base directory for Briefcase project.
+        :param data_path: Base directory for Briefcase tools, support packages, etc.
+        :param is_clone: Flag that Command was triggered by the user's requested Command;
+            for instance, RunCommand can invoke UpdateCommand and/or BuildCommand.
+        """
+        if base_path is None:
+            self.base_path = Path.cwd()
+        else:
+            self.base_path = base_path
+        self.data_path = self.validate_data_path(data_path)
+        self.apps = {} if apps is None else apps
+        self.is_clone = is_clone
 
-        # If a home path is provided during construction, use it. This usually
-        # indicates we're under test conditions.
-        if home_path is None:
-            home_path = Path.home()
-        self.home_path = Path(home_path)
-
-        # If a data path is provided during construction, use it. This usually
-        # indicates we're under test conditions. If there's no data path
-        # provided, look for a BRIEFCASE_HOME environment variable. If that
-        # isn't defined, use a platform-specific default data path.
-        if data_path is None:
-            try:
-                briefcase_home = os.environ["BRIEFCASE_HOME"]
-                data_path = Path(briefcase_home).resolve()
-                # Path("") converts to ".", so check for that edge case.
-                if briefcase_home == "" or not data_path.exists():
-                    raise BriefcaseCommandError(
-                        "The path specified by BRIEFCASE_HOME does not exist."
-                    )
-            except KeyError:
-                if self.host_os == "Darwin":
-                    # macOS uses a bundle name, rather than just the app name
-                    app_name = "org.beeware.briefcase"
-                else:
-                    app_name = "briefcase"
-
-                data_path = PlatformDirs(
-                    appname=app_name,
-                    appauthor="BeeWare",
-                ).user_cache_path
-
-        if " " in os.fsdecode(data_path):
-            raise BriefcaseCommandError(
-                f"""
-The location Briefcase will use to store tools and support files:
-
-    {data_path}
-
-contains spaces. This will cause problems with some tools, preventing
-you from building and packaging applications.
-
-You can set the environment variable BRIEFCASE_HOME to specify
-a custom location for Briefcase's tools.
-
-"""
-            )
-
-        self.data_path = Path(data_path)
-
-        self.tools_path = self.data_path / "tools"
+        self.tools = tools or ToolCache(
+            logger=logger,
+            console=console,
+            base_path=self.data_path / "tools",
+        )
 
         self.global_config = None
-        self.apps = {} if apps is None else apps
         self._path_index = {}
 
-        # External service APIs.
-        # These are abstracted to enable testing without patching.
-        self.cookiecutter = cookiecutter
-        self.requests = requests
-        self.input = Console(enabled=input_enabled)
-        self.os = os
-        self.sys = sys
-        self.stdlib_platform = platform
-        self.shutil = shutil
-        self.subprocess = Subprocess(self)
+    @property
+    def logger(self):
+        return self.tools.logger
 
-        # The internal Briefcase integrations API.
-        self.integrations = integrations
-
-        # Initialize default logger (replaced when options are parsed).
-        self.logger = Log()
-        self.save_log = False
+    @property
+    def input(self):
+        return self.tools.input
 
     def check_obsolete_data_dir(self):
         """Inform user if obsolete data directory exists.
@@ -210,7 +166,7 @@ a custom location for Briefcase's tools.
         downloads, tools, etc. This check lets users know the old
         directory still exists and their options to migrate or clean up.
         """
-        dot_briefcase_path = self.home_path / ".briefcase"
+        dot_briefcase_path = self.tools.home_path / ".briefcase"
 
         # If there's no .briefcase path, no need to check for migration.
         if not dot_briefcase_path.exists():
@@ -281,83 +237,101 @@ or delete the old data directory, and re-run Briefcase.
             # Create data directory to prevent full notice showing again.
             self.data_path.mkdir(parents=True, exist_ok=True)
 
-    @property
-    def create_command(self):
-        """Factory property; return an instance of a create command for the
-        same format."""
+    def validate_data_path(self, data_path):
+        """Validate provided data path or determine OS-specific path.
+
+        If a data path is provided during construction, use it. This
+        usually indicates we're under test conditions. If there's no
+        data path provided, look for a BRIEFCASE_HOME environment
+        variable. If that isn't defined, use a platform-specific default
+        data path.
+        """
+        if data_path is None:
+            try:
+                briefcase_home = os.environ["BRIEFCASE_HOME"]
+                data_path = Path(briefcase_home).resolve()
+                # Path("") converts to ".", so check for that edge case.
+                if briefcase_home == "" or not data_path.exists():
+                    raise BriefcaseCommandError(
+                        "The path specified by BRIEFCASE_HOME does not exist."
+                    )
+            except KeyError:
+                if platform.system() == "Darwin":
+                    # macOS uses a bundle name, rather than just the app name
+                    app_name = "org.beeware.briefcase"
+                else:
+                    app_name = "briefcase"
+
+                data_path = PlatformDirs(
+                    appname=app_name,
+                    appauthor="BeeWare",
+                ).user_cache_path
+
+        if " " in os.fsdecode(data_path):
+            raise BriefcaseCommandError(
+                f"""
+The location Briefcase will use to store tools and support files:
+
+    {data_path}
+
+contains spaces. This will cause problems with some tools, preventing
+you from building and packaging applications.
+
+You can set the environment variable BRIEFCASE_HOME to specify
+a custom location for Briefcase's tools.
+
+"""
+            )
+
+        return Path(data_path)
+
+    def _command_factory(self, command_name: str):
+        """Command factory for the current platform and format.
+
+        :param command_name: name of Command (e.g. 'create', 'build', 'run', etc.)
+        :return: instantiated Command
+        """
         format_module = importlib.import_module(self.__module__)
-        command = format_module.create(
+        command = getattr(format_module, command_name)(
             base_path=self.base_path,
             apps=self.apps,
-            input_enabled=self.input.enabled,
+            logger=self.logger,
+            console=self.input,
+            tools=self.tools,
+            is_clone=True,
         )
         command.clone_options(self)
         return command
 
+    @property
+    def create_command(self):
+        """Create Command factory for the same platform and format."""
+        return self._command_factory("create")
+
     @property
     def update_command(self):
-        """Factory property; return an instance of an update command for the
-        same format."""
-        format_module = importlib.import_module(self.__module__)
-        command = format_module.update(
-            base_path=self.base_path,
-            apps=self.apps,
-            input_enabled=self.input.enabled,
-        )
-        command.clone_options(self)
-        return command
+        """Update Command factory for the same platform and format."""
+        return self._command_factory("update")
 
     @property
     def build_command(self):
-        """Factory property; return an instance of a build command for the same
-        format."""
-        format_module = importlib.import_module(self.__module__)
-        command = format_module.build(
-            base_path=self.base_path,
-            apps=self.apps,
-            input_enabled=self.input.enabled,
-        )
-        command.clone_options(self)
-        return command
+        """Build Command factory for the same platform and format."""
+        return self._command_factory("build")
 
     @property
     def run_command(self):
-        """Factory property; return an instance of a run command for the same
-        format."""
-        format_module = importlib.import_module(self.__module__)
-        command = format_module.run(
-            base_path=self.base_path,
-            apps=self.apps,
-            input_enabled=self.input.enabled,
-        )
-        command.clone_options(self)
-        return command
+        """Run Command factory for the same platform and format."""
+        return self._command_factory("run")
 
     @property
     def package_command(self):
-        """Factory property; return an instance of a package command for the
-        same format."""
-        format_module = importlib.import_module(self.__module__)
-        command = format_module.package(
-            base_path=self.base_path,
-            apps=self.apps,
-            input_enabled=self.input.enabled,
-        )
-        command.clone_options(self)
-        return command
+        """Package Command factory for the same platform and format."""
+        return self._command_factory("package")
 
     @property
     def publish_command(self):
-        """Factory property; return an instance of a publish command for the
-        same format."""
-        format_module = importlib.import_module(self.__module__)
-        command = format_module.publish(
-            base_path=self.base_path,
-            apps=self.apps,
-            input_enabled=self.input.enabled,
-        )
-        command.clone_options(self)
-        return command
+        """Publish Command factory for the same platform and format."""
+        return self._command_factory("publish")
 
     @property
     def platform_path(self):
@@ -396,7 +370,7 @@ or delete the old data directory, and re-run Briefcase.
         packaging format.
 
         This is the single file that should be uploaded for distribution.
-        This may be the binary (if the binary is a self contained executable);
+        This may be the binary (if the binary is a self-contained executable);
         however, if the output format produces an installer, it will be the
         path to the installer.
 
@@ -429,6 +403,34 @@ or delete the old data directory, and re-run Briefcase.
             path_index = self._load_path_index(app)
         return self.bundle_path(app) / path_index["support_path"]
 
+    def support_revision(self, app: BaseConfig):
+        """Obtain the support package revision that the template requires.
+
+        :param app: The config object for the app
+        :return: The support revision required by the template.
+        """
+        # If the index file hasn't been loaded for this app, load it.
+        try:
+            path_index = self._path_index[app]
+        except KeyError:
+            path_index = self._load_path_index(app)
+        return path_index["support_revision"]
+
+    def cleanup_paths(self, app: BaseConfig):
+        """Obtain the paths generated by the app template that should be
+        cleaned up prior to release.
+
+        :param app: The config object for the app
+        :return: The list of path globs inside the app template that should
+            be cleaned up.
+        """
+        # If the index file hasn't been loaded for this app, load it.
+        try:
+            path_index = self._path_index[app]
+        except KeyError:
+            path_index = self._load_path_index(app)
+        return path_index["cleanup_paths"]
+
     def app_requirements_path(self, app: BaseConfig):
         """Obtain the path into which a requirements.txt file should be
         written.
@@ -480,17 +482,17 @@ or delete the old data directory, and re-run Briefcase.
             for path in app.sources
             if path.rsplit("/", 1)[-1] == app.module_name
         ]
-        try:
-            if len(app_home) == 1:
-                path = Path(str(self.base_path), *app_home[0])
-            else:
-                raise BriefcaseCommandError(
-                    f"Multiple paths in sources found for application '{app.app_name}'"
-                )
-        except IndexError as e:
+
+        if len(app_home) == 0:
             raise BriefcaseCommandError(
-                f"Unable to find code for application '{app.app_name}'"
-            ) from e
+                f"Unable to find code for application {app.app_name!r}"
+            )
+        elif len(app_home) == 1:
+            path = Path(str(self.base_path), *app_home[0])
+        else:
+            raise BriefcaseCommandError(
+                f"Multiple paths in sources found for application {app.app_name!r}"
+            )
 
         return path
 
@@ -499,9 +501,11 @@ or delete the old data directory, and re-run Briefcase.
         """The major.minor of the Python version in use, as a string.
 
         This is used as a repository label/tag to identify the
-        appropriate templates, etc to use.
+        appropriate templates, etc. to use.
         """
-        return f"{self.sys.version_info.major}.{self.sys.version_info.minor}"
+        return (
+            f"{self.tools.sys.version_info.major}.{self.tools.sys.version_info.minor}"
+        )
 
     def verify_tools(self):
         """Verify that the tools needed to run this command exist.
@@ -511,6 +515,10 @@ or delete the old data directory, and re-run Briefcase.
         """
         pass
 
+    def verify_app_tools(self, app: BaseConfig):
+        """Verify that tools needed to run the command for this app exist."""
+        pass
+
     def parse_options(self, extra):
         parser = argparse.ArgumentParser(
             prog=self.cmd_line.format(
@@ -532,7 +540,7 @@ or delete the old data directory, and re-run Briefcase.
         # Extract the base default options onto the command
         self.input.enabled = options.pop("input_enabled")
         self.logger.verbosity = options.pop("verbosity")
-        self.save_log = options.pop("save_log")
+        self.logger.save_log = options.pop("save_log")
 
         return options
 
@@ -541,8 +549,7 @@ or delete the old data directory, and re-run Briefcase.
 
         :param command: The command whose options are to be cloned
         """
-        self.input.enabled = command.input.enabled
-        self.logger = command.logger
+        pass
 
     def add_default_options(self, parser):
         """Add the default options that exist on *all* commands.
@@ -612,62 +619,11 @@ or delete the old data directory, and re-run Briefcase.
 
         except FileNotFoundError as e:
             raise BriefcaseConfigError(
-                f"""Configuration file not found. Did you run briefcase in the directory that contains {filename!r}?"""
+                f"""Configuration file not found.
+
+Did you run Briefcase in a project directory that contains {filename.name!r}?"""
             ) from e
 
-    def download_url(self, url, download_path):
-        """Download a given URL, caching it. If it has already been downloaded,
-        return the value that has been cached.
-
-        This is a utility method used to obtain assets used by the
-        install process. The cached filename will be the filename portion of
-        the URL, appended to the download path.
-
-        :param url: The URL to download
-        :param download_path: The path to the download cache folder. This path
-            will be created if it doesn't exist.
-        :returns: The filename of the downloaded (or cached) file.
-        """
-        download_path.mkdir(parents=True, exist_ok=True)
-
-        response = self.requests.get(url, stream=True)
-        if response.status_code == 404:
-            raise MissingNetworkResourceError(url=url)
-        elif response.status_code != 200:
-            raise BadNetworkResourceError(url=url, status_code=response.status_code)
-
-        # The initial URL might (read: will) go through URL redirects, so
-        # we need the *final* response. We look at either the `Content-Disposition`
-        # header, or the final URL, to extract the cache filename.
-        cache_full_name = urlparse(response.url).path
-        header_value = response.headers.get("Content-Disposition")
-        if header_value:
-            # See also https://tools.ietf.org/html/rfc6266
-            value, parameters = parse_header(header_value)
-            content_type = value.split(":", 1)[-1].strip().lower()
-            if content_type == "attachment" and parameters.get("filename"):
-                cache_full_name = parameters["filename"]
-        cache_name = cache_full_name.split("/")[-1]
-        filename = download_path / cache_name
-        if not filename.exists():
-            # We have meaningful content, and it hasn't been cached previously,
-            # so save it in the requested location
-            self.logger.info(f"Downloading {cache_name}...")
-            with filename.open("wb") as f:
-                total = response.headers.get("content-length")
-                if total is None:
-                    f.write(response.content)
-                else:
-                    progress_bar = self.input.progress_bar()
-                    task_id = progress_bar.add_task("Downloader", total=int(total))
-                    with progress_bar:
-                        for data in response.iter_content(chunk_size=1024 * 1024):
-                            f.write(data)
-                            progress_bar.update(task_id, advance=len(data))
-        else:
-            self.logger.info(f"{cache_name} already downloaded")
-        return filename
-
     def update_cookiecutter_cache(self, template: str, branch="master"):
         """Ensure that we have a current checkout of a template path.
 
@@ -693,12 +649,12 @@ or delete the old data directory, and re-run Briefcase.
             # fall back to using the specified template directly.
             try:
                 cached_template = cookiecutter_cache_path(template)
-                repo = self.git.Repo(cached_template)
+                repo = self.tools.git.Repo(cached_template)
                 try:
                     # Attempt to update the repository
                     remote = repo.remote(name="origin")
                     remote.fetch()
-                except self.git.exc.GitCommandError:
+                except self.tools.git.exc.GitCommandError:
                     # We are offline, or otherwise unable to contact
                     # the origin git repo. It's OK to continue; but warn
                     # the user that the template may be stale.
@@ -727,11 +683,11 @@ or delete the old data directory, and re-run Briefcase.
                 except IndexError as e:
                     # No branch exists for the requested version.
                     raise TemplateUnsupportedVersion(branch) from e
-            except self.git.exc.NoSuchPathError:
+            except self.tools.git.exc.NoSuchPathError:
                 # Template cache path doesn't exist.
                 # Just use the template directly, rather than attempting an update.
                 cached_template = template
-            except self.git.exc.InvalidGitRepositoryError:
+            except self.tools.git.exc.InvalidGitRepositoryError:
                 # Template cache path exists, but isn't a git repository
                 # Just use the template directly, rather than attempting an update.
                 cached_template = template
@@ -740,3 +696,39 @@ or delete the old data directory, and re-run Briefcase.
             cached_template = template
 
         return cached_template
+
+    def generate_template(self, template, branch, output_path, extra_context):
+        """Ensure the named template is up-to-date for the given branch, and
+        roll out that template.
+
+        :param template: The template URL or path to generate
+        :param branch: The branch of the template to use
+        :param output_path: The filesystem path where the template will be generated.
+        :param extra_context: Extra context to pass to the cookiecutter template
+        """
+        # Make sure we have an updated cookiecutter template,
+        # checked out to the right branch
+        cached_template = self.update_cookiecutter_cache(
+            template=template, branch=branch
+        )
+
+        try:
+            # Unroll the template
+            self.tools.cookiecutter(
+                str(cached_template),
+                no_input=True,
+                output_dir=str(output_path),
+                checkout=branch,
+                extra_context=extra_context,
+            )
+        except subprocess.CalledProcessError as e:
+            # Computer is offline
+            # status code == 128 - certificate validation error.
+            raise NetworkFailure("clone template repository") from e
+        except cookiecutter_exceptions.RepositoryNotFound as e:
+            # Either the template path is invalid,
+            # or it isn't a cookiecutter template (i.e., no cookiecutter.json)
+            raise InvalidTemplateRepository(template) from e
+        except cookiecutter_exceptions.RepositoryCloneFailed as e:
+            # Branch does not exist.
+            raise TemplateUnsupportedVersion(branch) from e
