@@ -62,9 +62,10 @@ class DevCommand(BaseCommand):
         if app.requires:
             with self.input.wait_bar("Installing dev dependencies..."):
                 try:
-                    self.subprocess.run(
+                    self.tools.subprocess.run(
                         [
                             sys.executable,
+                            "-u",
                             "-m",
                             "pip",
                             "install",
@@ -86,9 +87,10 @@ class DevCommand(BaseCommand):
         """
         try:
             # Invoke the app.
-            self.subprocess.run(
+            self.tools.subprocess.run(
                 [
                     sys.executable,
+                    "-u",
                     "-c",
                     (
                         "import runpy, sys;"
@@ -98,7 +100,8 @@ class DevCommand(BaseCommand):
                 ],
                 env=env,
                 check=True,
-                cwd=self.home_path,
+                cwd=self.tools.home_path,
+                stream_output=True,
             )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(
@@ -142,6 +145,8 @@ class DevCommand(BaseCommand):
                 "Project specifies more than one application; use --app to specify which one to start."
             )
 
+        self.verify_app_tools(app)
+
         # Look for the existence of a dist-info file.
         # If one exists, assume that the dependencies have already been
         # installed. If a dependency update has been manually requested,
