@@ -44,6 +44,8 @@ class UpdateCommand(CreateCommand):
             )
             return
 
+        self.verify_app_tools(app)
+
         if update_dependencies:
             self.logger.info("Updating dependencies...", prefix=app.app_name)
             self.install_app_dependencies(app=app)
@@ -57,6 +59,9 @@ class UpdateCommand(CreateCommand):
             )
             self.install_app_resources(app=app)
 
+        self.logger.info("Removing unneeded app content...", prefix=app.app_name)
+        self.cleanup_app_content(app=app)
+
         self.logger.info("Application updated.", prefix=app.app_name)
 
     def __call__(
