@@ -1,6 +1,7 @@
 class BriefcaseError(Exception):
-    def __init__(self, error_code):
+    def __init__(self, error_code, skip_logfile=False):
         self.error_code = error_code
+        self.skip_logfile = skip_logfile
 
 
 class HelpText(BriefcaseError):
@@ -8,33 +9,38 @@ class HelpText(BriefcaseError):
     an error."""
 
 
-class NoCommandError(HelpText):
+class InfoHelpText(HelpText):
     def __init__(self, msg):
-        super().__init__(-10)
+        super().__init__(error_code=0, skip_logfile=True)
         self.msg = msg
 
     def __str__(self):
         return self.msg
 
 
-class ShowOutputFormats(HelpText):
+class NoCommandError(HelpText):
+    def __init__(self, msg):
+        super().__init__(error_code=-10, skip_logfile=True)
+        self.msg = msg
+
+    def __str__(self):
+        return self.msg
+
+
+class ShowOutputFormats(InfoHelpText):
     def __init__(self, platform, default, choices):
-        super().__init__(0)
+        super().__init__(
+            f"Available formats for {platform}: {', '.join(sorted(choices))}\n"
+            f"Default format: {default}"
+        )
         self.platform = platform
         self.default = default
         self.choices = choices
 
-    def __str__(self):
-        choices = ", ".join(sorted(self.choices))
-        return (
-            f"Available formats for {self.platform}: {choices}\n"
-            f"Default format: {self.default}"
-        )
-
 
 class InvalidFormatError(BriefcaseError):
     def __init__(self, requested, choices):
-        super().__init__(-21)
+        super().__init__(error_code=-21, skip_logfile=True)
         self.requested = requested
         self.choices = choices
 
@@ -45,7 +51,7 @@ class InvalidFormatError(BriefcaseError):
 
 class UnsupportedCommandError(BriefcaseError):
     def __init__(self, platform, output_format, command):
-        super().__init__(-30)
+        super().__init__(error_code=-30, skip_logfile=True)
         self.platform = platform
         self.output_format = output_format
         self.command = command
@@ -59,7 +65,7 @@ class UnsupportedCommandError(BriefcaseError):
 
 class BriefcaseConfigError(BriefcaseError):
     def __init__(self, msg):
-        super().__init__(100)
+        super().__init__(error_code=100, skip_logfile=True)
         self.msg = msg
 
     def __str__(self):
@@ -68,7 +74,7 @@ class BriefcaseConfigError(BriefcaseError):
 
 class BriefcaseCommandError(BriefcaseError):
     def __init__(self, msg):
-        super().__init__(200)
+        super().__init__(error_code=200)
         self.msg = msg
 
     def __str__(self):
