@@ -2,6 +2,7 @@ from . import (
     android_sdk,
     cookiecutter,
     docker,
+    download,
     flatpak,
     git,
     java,
@@ -17,6 +18,7 @@ __all__ = [
     "android_sdk",
     "cookiecutter",
     "docker",
+    "download",
     "flatpak",
     "git",
     "java",
