@@ -1,12 +1,12 @@
 from briefcase.exceptions import BriefcaseCommandError
 
 
-def verify_git_is_installed(command):
+def verify_git_is_installed(tools):
     """Verify if git is installed.
 
     Unfortunately, `import git` triggers a call on the operating system
     to run the git executable. On some platforms (notably macOS), the git
-    binary has been instrumented such that if git *isnt'* installed,
+    binary has been instrumented such that if git *isn't* installed,
     running git triggers a prompt to install Xcode. However, that messes
     with the UX workflow.
 
@@ -15,20 +15,22 @@ def verify_git_is_installed(command):
     workflows, and ensures that "briefcase --help" works on other platforms
     without raising an error.
 
-    :param command: The command that needs to perform the verification check.
+    :param tools: ToolCache of available tools
     :returns: The git module, if `git` is installed and available.
     """
+    # short circuit since already verified and available
+    if hasattr(tools, "git"):
+        return tools.git
+
     # Check whether the git executable could be imported.
     try:
         import git
-
-        return git
-    except ImportError as e:
+    except ImportError as e:  # pragma: no cover
         # macOS provides git as part of the Xcode command line tools,
         # and also hijacks /usr/bin/git with a trigger that prompts the
         # installation of those tools. Customize the message to account
         # for this.
-        if command.host_os == "Darwin":
+        if tools.host_os == "Darwin":
             raise BriefcaseCommandError(
                 """\
 Briefcase requires git, but it is not installed. Xcode provides git; you should
@@ -59,3 +61,6 @@ If you have installed git recently and are still getting this error, you may
 need to restart your terminal session.
 """
             ) from e
+
+    tools.git = git
+    return git
