@@ -4,76 +4,84 @@ from abc import abstractmethod
 from pathlib import Path
 from urllib.parse import urlparse
 
-from requests import exceptions as requests_exceptions
-
 from briefcase.exceptions import (
     BriefcaseCommandError,
     CorruptToolError,
     MissingToolError,
-    NetworkFailure,
 )
 
+ELF_HEADER_IDENT = bytes.fromhex("7F454C46")
 ELF_PATCH_OFFSET = 0x08
 ELF_PATCH_ORIGINAL_BYTES = bytes.fromhex("414902")
 ELF_PATCH_PATCHED_BYTES = bytes.fromhex("000000")
 
 
 class LinuxDeployBase:
-    def __init__(self, command):
-        self.command = command
+    def __init__(self, tools, **kwargs):
+        self.tools = tools
 
     @property
     @abstractmethod
     def file_name(self):
         """The name of the executable file for the tool/plugin, excluding the
         path."""
-        ...  # pragma: no cover
 
     @property
     @abstractmethod
     def download_url(self):
         """The URL where the tool/plugin can be downloaded."""
-        ...  # pragma: no cover
 
     @property
     @abstractmethod
     def file_path(self):
         """The folder on the local filesystem that contains the file_name."""
-        ...  # pragma: no cover
 
     def exists(self):
         return (self.file_path / self.file_name).exists()
 
     def install(self):
         """Download and install linuxdeploy or plugin."""
-        try:
-            download_path = self.command.download_url(
-                url=self.download_url,
-                download_path=self.file_path,
-            )
-        except requests_exceptions.ConnectionError as e:
-            raise NetworkFailure(f"download {self.full_name}") from e
+        self.tools.download.file(
+            url=self.download_url,
+            download_path=self.file_path,
+            role=self.full_name,
+        )
 
-        with self.command.input.wait_bar(f"Installing {self.full_name}..."):
-            self.command.os.chmod(download_path, 0o755)
-            if self.file_name.endswith("AppImage"):
+        self.prepare_executable()
+
+    def prepare_executable(self):
+        """Update linuxdeploy and its plugins to allow execution.
+
+        All files must be made executable to run or for linuxdeploy to
+        use them as plugins while building the AppImage. ELF files need
+        special "magic" bytes zeroed to run properly in Docker.
+        """
+        with self.tools.input.wait_bar(f"Installing {self.file_name}..."):
+            self.tools.os.chmod(self.file_path / self.file_name, 0o755)
+            if self.is_elf_file():
                 self.patch_elf_header()
 
     @classmethod
-    def verify(cls, command, install=True, **kwargs):
+    def verify(cls, tools, install=True, **kwargs):
         """Verify that linuxdeploy tool or plugin is available.
 
-        :param command: The command that needs to use linuxdeploy
+        :param tools: ToolCache of available tools
         :param install: Should the tool/plugin be installed if it is not found?
         :param kwargs: Any additional keyword arguments that should be passed
             to the tool at time of construction.
         :returns: A valid tool wrapper. If the tool/plugin is not
             available, and was not installed, raises MissingToolError.
         """
-        tool = cls(command, **kwargs)
+        is_plugin = issubclass(cls, LinuxDeployPluginBase)
+
+        # short circuit since already verified and available
+        if not is_plugin and hasattr(tools, "linuxdeploy"):
+            return tools.linuxdeploy
+
+        tool = cls(tools, **kwargs)
         if not tool.exists():
             if install:
-                command.logger.info(
+                tools.logger.info(
                     cls.install_msg.format(full_name=cls.full_name),
                     prefix="linuxdeploy",
                 )
@@ -81,11 +89,14 @@ class LinuxDeployBase:
             else:
                 raise MissingToolError(cls.name)
 
+        if not is_plugin:
+            tools.linuxdeploy = tool
+
         return tool
 
     def uninstall(self):
         """Uninstall tool."""
-        with self.command.input.wait_bar(f"Removing old {self.full_name} install..."):
+        with self.tools.input.wait_bar(f"Removing old {self.full_name} install..."):
             (self.file_path / self.file_name).unlink()
 
     def upgrade(self):
@@ -96,9 +107,18 @@ class LinuxDeployBase:
         self.uninstall()
         self.install()
 
+    def is_elf_file(self):
+        """Returns True if the file is an ELF object file.
+
+        The header for an ELF object file always starts with 0x7F454C46;
+        this is 0x7fELF if you interpret the last three bytes as ASCII.
+        """
+        with (self.file_path / self.file_name).open("r+b") as file:
+            return file.read(len(ELF_HEADER_IDENT)) == ELF_HEADER_IDENT
+
     def patch_elf_header(self):
-        """Patch the ELF header of the AppImage to ensure it's always
-        executable.
+        """Patch the ELF header of the AppImage to ensure it can successfully
+        run in all contexts.
 
         This patch is necessary on Linux hosts that use AppImageLauncher.
         AppImages use a modified ELF binary header starting at offset 0x08
@@ -122,13 +142,13 @@ class LinuxDeployBase:
                 appimage.write(ELF_PATCH_PATCHED_BYTES)
                 appimage.flush()
                 appimage.seek(0)
-                self.command.logger.info("Patched ELF header of linuxdeploy AppImage.")
+                self.tools.logger.info(f"Patched ELF header for {self.file_name}.")
             # Else if the header is the patched value, do nothing.
             elif (
                 appimage.read(len(ELF_PATCH_ORIGINAL_BYTES)) == ELF_PATCH_PATCHED_BYTES
             ):
-                self.command.logger.info(
-                    "ELF header of linuxdeploy AppImage is already patched."
+                self.tools.logger.info(
+                    f"ELF header for {self.file_name} is already patched."
                 )
             else:
                 # We should only get here if the file at the AppImage patch doesn't have
@@ -155,7 +175,7 @@ class LinuxDeployPluginBase(LinuxDeployBase):
 
     @property
     def file_path(self):
-        return self.command.tools_path / "linuxdeploy_plugins" / self.plugin_id
+        return self.tools.base_path / "linuxdeploy_plugins" / self.plugin_id
 
 
 class LinuxDeployGtkPlugin(LinuxDeployPluginBase):
@@ -178,7 +198,7 @@ class LinuxDeployQtPlugin(LinuxDeployPluginBase):
 
     @property
     def file_name(self):
-        return f"linuxdeploy-plugin-qt-{self.command.host_arch}.AppImage"
+        return f"linuxdeploy-plugin-qt-{self.tools.host_arch}.AppImage"
 
     @property
     def download_url(self):
@@ -192,13 +212,13 @@ class LinuxDeployLocalFilePlugin(LinuxDeployPluginBase):
     full_name = "user-provided linuxdeploy plugin from local file"
     install_msg = "Copying user-provided plugin into project"
 
-    def __init__(self, command, plugin_path, bundle_path):
+    def __init__(self, tools, plugin_path, bundle_path):
         self._file_name = plugin_path.name
         self.local_path = plugin_path.parent
         self._file_path = bundle_path
 
         # Call the super last to ensure validation of the filename
-        super().__init__(command)
+        super().__init__(tools)
 
     @property
     def file_name(self):
@@ -217,7 +237,7 @@ class LinuxDeployLocalFilePlugin(LinuxDeployPluginBase):
         # folder. This is required to ensure that the file is available inside
         # the Docker context.
         try:
-            self.command.shutil.copy(
+            self.tools.shutil.copy(
                 self.local_path / self.file_name,
                 self.file_path / self.file_name,
             )
@@ -227,18 +247,20 @@ class LinuxDeployLocalFilePlugin(LinuxDeployPluginBase):
                 "Is the path correct?"
             )
 
+        self.prepare_executable()
+
 
 class LinuxDeployURLPlugin(LinuxDeployPluginBase):
     full_name = "user-provided linuxdeploy plugin from URL"
 
-    def __init__(self, command, url):
+    def __init__(self, tools, url):
         self._download_url = url
 
         url_parts = urlparse(url)
         self._file_name = url_parts.path.split("/")[-1]
 
         # Build a hash of the download URL; this hash is used to
-        # idenfity plugins downloaded from different sources. We don't
+        # identify plugins downloaded from different sources. We don't
         # just use the domain, because we need:
         #  * http://example.com/release/linuxdeploy-plugin-foobar.sh
         #  * http://example.com/dev/linuxdeploy-plugin-foobar.sh
@@ -248,7 +270,7 @@ class LinuxDeployURLPlugin(LinuxDeployPluginBase):
         self.hash = hashlib.sha256(url.encode("utf-8"))
 
         # Call the super last to ensure validation of the filename
-        super().__init__(command)
+        super().__init__(tools)
 
     @property
     def file_name(self):
@@ -257,7 +279,7 @@ class LinuxDeployURLPlugin(LinuxDeployPluginBase):
     @property
     def file_path(self):
         return (
-            self.command.tools_path
+            self.tools.base_path
             / "linuxdeploy_plugins"
             / self.plugin_id
             / self.hash.hexdigest()
@@ -279,11 +301,11 @@ class LinuxDeploy(LinuxDeployBase):
 
     @property
     def file_path(self):
-        return self.command.tools_path
+        return self.tools.base_path
 
     @property
     def file_name(self):
-        return f"linuxdeploy-{self.command.host_arch}.AppImage"
+        return f"linuxdeploy-{self.tools.host_arch}.AppImage"
 
     @property
     def download_url(self):
@@ -308,7 +330,7 @@ class LinuxDeploy(LinuxDeployBase):
          * A URL
          * A local file.
 
-        This definition can be preceeded by environment variables that must
+        This definition can be preceded by environment variables that must
         exist in the environment. For example, a plugin definition of:
 
             DEPLOY_GTK_VERSION=3 FOO='bar whiz' gtk
@@ -332,17 +354,17 @@ class LinuxDeploy(LinuxDeployBase):
 
             try:
                 plugin_klass = self.plugins[plugin_name]
-                self.command.logger.info(f"Using default {plugin_name} plugin")
+                self.tools.logger.info(f"Using default {plugin_name} plugin")
 
-                plugin = plugin_klass.verify(self.command)
+                plugin = plugin_klass.verify(self.tools)
             except KeyError:
                 if plugin_name.startswith(("https://", "http://")):
-                    self.command.logger.info(f"Using URL plugin {plugin_name}")
-                    plugin = LinuxDeployURLPlugin.verify(self.command, url=plugin_name)
+                    self.tools.logger.info(f"Using URL plugin {plugin_name}")
+                    plugin = LinuxDeployURLPlugin.verify(self.tools, url=plugin_name)
                 else:
-                    self.command.logger.info(f"Using local file plugin {plugin_name}")
+                    self.tools.logger.info(f"Using local file plugin {plugin_name}")
                     plugin = LinuxDeployLocalFilePlugin.verify(
-                        self.command,
+                        self.tools,
                         plugin_path=Path(plugin_name),
                         bundle_path=bundle_path,
                     )
