@@ -183,26 +183,26 @@ you can re-run Briefcase.
                 line for line in output.split("\n") if line.startswith("Xcode ")
             ]
             if version_lines:
-                try:
-                    # Split the content after the first space
-                    # and split that content on the dots.
-                    # Append 0's to fill any gaps caused by
-                    # version numbers that don't have a minor version.
-                    version = tuple(
-                        int(v) for v in version_lines[0].split(" ")[1].split(".")
-                    ) + (0, 0)
+                # Split the content after the first space
+                # and split that content on the dots.
+                # Append 0's to fill any gaps caused by
+                # version numbers that don't have a minor version.
+                # At this point, version lines *must* have at least one element,
+                # and each line *must* have a string with at least one space,
+                # so if either array lookup fails, something weird is happening.
+                version = tuple(
+                    int(v) for v in version_lines[0].split(" ")[1].split(".")
+                ) + (0, 0)
 
-                    if version < min_version:
-                        min_version = ".".join(str(v) for v in min_version)
-                        version = ".".join(str(v) for v in version)
-                        raise BriefcaseCommandError(
-                            f"Xcode {min_version} is required; {version} is installed. Please update Xcode."
-                        )
-                    else:
-                        # Version number is acceptable
-                        return
-                except IndexError:
-                    pass
+                if version < min_version:
+                    min_version = ".".join(str(v) for v in min_version)
+                    version = ".".join(str(v) for v in version)
+                    raise BriefcaseCommandError(
+                        f"Xcode {min_version} is required; {version} is installed. Please update Xcode."
+                    )
+                else:
+                    # Version number is acceptable
+                    return
 
             tools.logger.warning(
                 """
