@@ -1,10 +1,10 @@
 import os
 import subprocess
-from contextlib import contextmanager
 
 from briefcase.commands import (
     BuildCommand,
     CreateCommand,
+    OpenCommand,
     PackageCommand,
     PublishCommand,
     RunCommand,
@@ -12,22 +12,29 @@ from briefcase.commands import (
 )
 from briefcase.config import AppConfig
 from briefcase.exceptions import BriefcaseCommandError
-from briefcase.integrations.docker import verify_docker
+from briefcase.integrations.docker import Docker, DockerAppContext
 from briefcase.integrations.linuxdeploy import LinuxDeploy
+from briefcase.integrations.subprocess import NativeAppContext
 from briefcase.platforms.linux import LinuxMixin
 
 
-class LinuxAppImageMixin(LinuxMixin):
+class LinuxAppImagePassiveMixin(LinuxMixin):
+    # The Passive mixin honors the docker options, but doesn't try to verify
+    # docker exists. It is used by commands that are "passive" from the
+    # perspective of the build system, like open and run.
     output_format = "appimage"
 
     def appdir_path(self, app):
         return self.bundle_path(app) / f"{app.formal_name}.AppDir"
 
+    def project_path(self, app):
+        return self.bundle_path(app)
+
     def binary_path(self, app):
         binary_name = app.formal_name.replace(" ", "_")
         return (
             self.platform_path
-            / f"{binary_name}-{app.version}-{self.host_arch}.AppImage"
+            / f"{binary_name}-{app.version}-{self.tools.host_arch}.AppImage"
         )
 
     def distribution_path(self, app, packaging_format):
@@ -46,9 +53,7 @@ class LinuxAppImageMixin(LinuxMixin):
     def parse_options(self, extra):
         """Extract the use_docker option."""
         options = super().parse_options(extra)
-
         self.use_docker = options.pop("use_docker")
-
         return options
 
     def clone_options(self, command):
@@ -56,6 +61,8 @@ class LinuxAppImageMixin(LinuxMixin):
         super().clone_options(command)
         self.use_docker = command.use_docker
 
+
+class LinuxAppImageMixin(LinuxAppImagePassiveMixin):
     def docker_image_tag(self, app):
         """The Docker image tag for an app."""
         return (
@@ -67,87 +74,74 @@ class LinuxAppImageMixin(LinuxMixin):
         Linux."""
         super().verify_tools()
         if self.use_docker:
-            if self.host_os == "Windows":
+            if self.tools.host_os == "Windows":
                 raise BriefcaseCommandError(
                     "Linux AppImages cannot be generated on Windows."
                 )
             else:
-                self.Docker = verify_docker(self)
-        elif self.host_os == "Linux":
-            # Use subprocess natively. No Docker wrapper is needed
-            self.Docker = None
-        else:
+                Docker.verify(tools=self.tools)
+        elif self.tools.host_os != "Linux":
             raise BriefcaseCommandError(
-                "Linux AppImages can only be generated on Linux."
+                "Linux AppImages can only be generated on Linux without Docker."
             )
 
-    @contextmanager
-    def dockerize(self, app):
-        """Enter a Docker container based on the properties of the app.
+    def verify_app_tools(self, app: AppConfig):
+        """Verify App environment is prepared and available.
 
-        Provides a context manager for the Docker context. The context
-        object is an object that exposes subprocess-analog calls.
+        When Docker is used, create or update a Docker image for the App.
+        Without Docker, the host machine will be used as the App environment.
 
-        This will replace self.subprocess with a version that proxies all
-        subprocess calls into the docker container.
-
-        If the user has selected --no-docker, this is a no-op.
-
-        :param app: The application that will determine the container image.
+        :param app: The application being built
         """
         if self.use_docker:
-            # Enter the Docker context.
-            self.logger.info("Entering Docker context...", prefix=app.app_name)
-            orig_subprocess = self.subprocess
-            self.subprocess = self.Docker(self, app)
-
-            yield self.subprocess
-
-            self.logger.info("Leaving Docker context", prefix=app.app_name)
-            self.subprocess = orig_subprocess
+            DockerAppContext.verify(
+                tools=self.tools,
+                app=app,
+                image_tag=self.docker_image_tag(app),
+                dockerfile_path=self.bundle_path(app) / "Dockerfile",
+                app_base_path=self.base_path,
+                host_platform_path=self.platform_path,
+                host_data_path=self.data_path,
+                python_version=self.python_version_tag,
+            )
         else:
-            yield self.subprocess
+            NativeAppContext.verify(tools=self.tools, app=app)
+
+        # Establish Docker as app context before letting super set subprocess
+        super().verify_app_tools(app)
 
 
 class LinuxAppImageCreateCommand(LinuxAppImageMixin, CreateCommand):
     description = "Create and populate a Linux AppImage."
 
-    @property
-    def support_package_url_query(self):
+    def support_package_filename(self, support_revision):
         """The query arguments to use in a support package query request."""
-        return [
-            ("platform", self.platform),
-            ("version", self.python_version_tag),
-            ("arch", self.host_arch),
-        ]
+        return f"Python-{self.python_version_tag}-linux-{self.tools.host_arch}-support.b{support_revision}.tar.gz"
 
-    def install_app_dependencies(self, app: AppConfig):
-        """Install application dependencies.
-
-        This will be containerized in Docker to ensure that the right
-        binary versions are installed.
-        """
-        with self.dockerize(app=app) as docker:
-            docker.prepare()
-
-            # Install dependencies. This will run inside a Docker container.
-            super().install_app_dependencies(app=app)
+    def support_package_url(self, support_revision):
+        """The URL of the support package to use for apps of this type."""
+        return (
+            "https://briefcase-support.s3.amazonaws.com/"
+            f"python/{self.python_version_tag}/{self.platform}/{self.tools.host_arch}/"
+            + self.support_package_filename(support_revision)
+        )
 
 
-class LinuxAppImageUpdateCommand(LinuxAppImageMixin, UpdateCommand):
+class LinuxAppImageUpdateCommand(LinuxAppImageCreateCommand, UpdateCommand):
     description = "Update an existing Linux AppImage."
 
 
+class LinuxAppImageOpenCommand(LinuxAppImagePassiveMixin, OpenCommand):
+    description = "Open the folder containing an existing Linux AppImage project."
+
+
 class LinuxAppImageBuildCommand(LinuxAppImageMixin, BuildCommand):
     description = "Build a Linux AppImage."
 
     def verify_tools(self):
-        """Verify that the AppImage linuxdeploy tool and plugins exist.
-
-        :param app: The application to build
-        """
+        """Verify the AppImage linuxdeploy tool and plugins exist."""
         super().verify_tools()
-        self.linuxdeploy = LinuxDeploy.verify(self)
+        LinuxDeploy.verify(tools=self.tools)
 
     def build_app(self, app: AppConfig, **kwargs):
         """Build an application.
@@ -159,20 +153,17 @@ class LinuxAppImageBuildCommand(LinuxAppImageMixin, BuildCommand):
 
         self.logger.info("Checking for Linuxdeploy plugins...", prefix=app.app_name)
         try:
-            plugins = self.linuxdeploy.verify_plugins(
+            plugins = self.tools.linuxdeploy.verify_plugins(
                 app.linuxdeploy_plugins,
                 bundle_path=self.bundle_path(app),
             )
 
             self.logger.info("Configuring Linuxdeploy plugins...", prefix=app.app_name)
             # We need to add the location of the linuxdeploy plugins to the PATH.
-            # However, if we arerunning inside Docker, we need to know the
+            # However, if we are running inside Docker, we need to know the
             # environment *inside* the Docker container.
-            if self.use_docker:
-                echo_cmd = ["/bin/bash", "-c", "echo $PATH"]
-                base_path = self.Docker(self, app).check_output(echo_cmd).strip()
-            else:
-                base_path = self.os.environ["PATH"]
+            echo_cmd = ["/bin/sh", "-c", "echo $PATH"]
+            base_path = self.tools[app].app_context.check_output(echo_cmd).strip()
 
             # Add any plugin-required environment variables
             for plugin in plugins.values():
@@ -199,6 +190,14 @@ class LinuxAppImageBuildCommand(LinuxAppImageMixin, BuildCommand):
                 # so this effectively silences a bunch of warnings that can't
                 # be easily resolved by the end user.
                 env["DISABLE_COPYRIGHT_FILES_DEPLOYMENT"] = "1"
+                # AppImages do not run natively within a Docker container. This
+                # treats the AppImage like a self-extracting executable. Using
+                # this environment variable instead of --appimage-extract-and-run
+                # is necessary to ensure AppImage plugins are extracted as well.
+                env["APPIMAGE_EXTRACT_AND_RUN"] = "1"
+                # Explicitly declare target architecture as the current architecture.
+                # This can be used by some linuxdeploy plugins.
+                env["ARCH"] = self.tools.host_arch
 
                 # Find all the .so files in app and app_packages,
                 # so they can be passed in to linuxdeploy to have their
@@ -215,43 +214,42 @@ class LinuxAppImageBuildCommand(LinuxAppImageMixin, BuildCommand):
                 for plugin in plugins:
                     additional_args.extend(["--plugin", plugin])
 
-                # Build the app image. We use `--appimage-extract-and-run`
-                # because AppImages won't run natively inside Docker.
-                with self.dockerize(app) as docker:
-                    docker.run(
-                        [
-                            self.linuxdeploy.file_path / self.linuxdeploy.file_name,
-                            "--appimage-extract-and-run",
-                            f"--appdir={self.appdir_path(app)}",
-                            "-d",
-                            os.fsdecode(
-                                self.appdir_path(app)
-                                / f"{app.bundle}.{app.app_name}.desktop"
-                            ),
-                            "-o",
-                            "appimage",
-                        ]
-                        + additional_args,
-                        env=env,
-                        check=True,
-                        cwd=self.platform_path,
-                    )
+                # Build the AppImage.
+                self.tools[app].app_context.run(
+                    [
+                        self.tools.linuxdeploy.file_path
+                        / self.tools.linuxdeploy.file_name,
+                        "--appdir",
+                        os.fsdecode(self.appdir_path(app)),
+                        "--desktop-file",
+                        os.fsdecode(
+                            self.appdir_path(app)
+                            / f"{app.bundle}.{app.app_name}.desktop"
+                        ),
+                        "--output",
+                        "appimage",
+                    ]
+                    + additional_args,
+                    env=env,
+                    check=True,
+                    cwd=self.platform_path,
+                )
 
                 # Make the binary executable.
-                self.os.chmod(self.binary_path(app), 0o755)
+                self.tools.os.chmod(self.binary_path(app), 0o755)
             except subprocess.CalledProcessError as e:
                 raise BriefcaseCommandError(
                     f"Error while building app {app.app_name}."
                 ) from e
 
 
-class LinuxAppImageRunCommand(LinuxAppImageMixin, RunCommand):
+class LinuxAppImageRunCommand(LinuxAppImagePassiveMixin, RunCommand):
     description = "Run a Linux AppImage."
 
     def verify_tools(self):
         """Verify that we're on Linux."""
         super().verify_tools()
-        if self.host_os != "Linux":
+        if self.tools.host_os != "Linux":
             raise BriefcaseCommandError("AppImages can only be executed on Linux.")
 
     def run_app(self, app: AppConfig, **kwargs):
@@ -261,12 +259,11 @@ class LinuxAppImageRunCommand(LinuxAppImageMixin, RunCommand):
         """
         self.logger.info("Starting app...", prefix=app.app_name)
         try:
-            self.subprocess.run(
-                [
-                    os.fsdecode(self.binary_path(app)),
-                ],
+            self.tools.subprocess.run(
+                [os.fsdecode(self.binary_path(app))],
                 check=True,
-                cwd=self.home_path,
+                cwd=self.tools.home_path,
+                stream_output=True,
             )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(f"Unable to start app {app.app_name}.") from e
@@ -283,6 +280,7 @@ class LinuxAppImagePublishCommand(LinuxAppImageMixin, PublishCommand):
 # Declare the briefcase command bindings
 create = LinuxAppImageCreateCommand  # noqa
 update = LinuxAppImageUpdateCommand  # noqa
+open = LinuxAppImageOpenCommand  # noqa
 build = LinuxAppImageBuildCommand  # noqa
 run = LinuxAppImageRunCommand  # noqa
 package = LinuxAppImagePackageCommand  # noqa
