@@ -1,10 +1,7 @@
-import os
-import tempfile
-from pathlib import Path
-
 from briefcase.commands import (
     BuildCommand,
     CreateCommand,
+    OpenCommand,
     PackageCommand,
     PublishCommand,
     RunCommand,
@@ -22,6 +19,9 @@ from briefcase.platforms.macOS import (
 class macOSAppMixin(macOSMixin):
     output_format = "app"
 
+    def project_path(self, app):
+        return self.binary_path(app) / "Contents"
+
     def binary_path(self, app):
         return self.bundle_path(app) / f"{app.formal_name}.app"
 
@@ -38,32 +38,15 @@ class macOSAppMixin(macOSMixin):
 class macOSAppCreateCommand(macOSAppMixin, CreateCommand):
     description = "Create and populate a macOS app."
 
-    def install_app_support_package(self, app: BaseConfig):
-        """Install the application support package.
 
-        :param app: The config object for the app
-        """
-        super().install_app_support_package(app)
-
-        # keep only Python lib from support package
-        lib_path = (
-            self.support_path(app).parent / "Support" / "Python" / "Resources" / "lib"
-        )
-
-        with tempfile.TemporaryDirectory() as tmpdir:
-            # TODO: Py3.8 compatibility; os.fsdecode not required in Py3.9
-            self.shutil.move(os.fsdecode(lib_path), os.fsdecode(tmpdir))
-            self.shutil.rmtree(self.support_path(app))
-
-            self.os.makedirs(Path(lib_path).parent)
-            # TODO: Py3.8 compatibility; os.fsdecode not required in Py3.9
-            self.shutil.move(os.fsdecode(Path(tmpdir) / "lib"), os.fsdecode(lib_path))
-
-
-class macOSAppUpdateCommand(macOSAppMixin, UpdateCommand):
+class macOSAppUpdateCommand(macOSAppCreateCommand, UpdateCommand):
     description = "Update an existing macOS app."
 
 
+class macOSAppOpenCommand(macOSAppMixin, OpenCommand):
+    description = "Open the app bundle folder for a macOS app."
+
+
 class macOSAppBuildCommand(macOSAppMixin, macOSSigningMixin, BuildCommand):
     description = "Build a macOS app."
 
@@ -95,6 +78,7 @@ class macOSAppPublishCommand(macOSAppMixin, PublishCommand):
 # Declare the briefcase command bindings
 create = macOSAppCreateCommand  # noqa
 update = macOSAppUpdateCommand  # noqa
+open = macOSAppOpenCommand  # noqa
 build = macOSAppBuildCommand  # noqa
 run = macOSAppRunCommand  # noqa
 package = macOSAppPackageCommand  # noqa
