@@ -1,11 +1,20 @@
 import os
 import subprocess
 import sys
+from unittest import mock
 
 import pytest
 import tomli_w
 
 from briefcase.commands.create import BriefcaseCommandError, DependencyInstallError
+from briefcase.integrations.subprocess import Subprocess
+
+
+@pytest.fixture
+def create_command(create_command, myapp):
+    # mock subprocess app context for this app
+    create_command.tools[myapp].app_context = mock.MagicMock(spec_set=Subprocess)
+    return create_command
 
 
 def create_installation_artefacts(app_packages_path, packages):
@@ -34,7 +43,6 @@ def create_installation_artefacts(app_packages_path, packages):
 def test_bad_path_index(create_command, myapp, bundle_path, app_requirements_path):
     """If the app's path index doesn't declare a destination for requirements,
     an error is raised."""
-
     # Write a briefcase.toml that is missing app_packages_path and app_requirements_path
     with (bundle_path / "briefcase.toml").open("wb") as f:
         index = {
@@ -56,7 +64,7 @@ def test_bad_path_index(create_command, myapp, bundle_path, app_requirements_pat
         create_command.install_app_dependencies(myapp)
 
     # pip wasn't invoked
-    create_command.subprocess.run.assert_not_called()
+    create_command.tools[myapp].app_context.run.assert_not_called()
 
     # requirements.txt doesn't exist either
     assert not app_requirements_path.exists()
@@ -74,7 +82,7 @@ def test_app_packages_no_requires(
     create_command.install_app_dependencies(myapp)
 
     # No request was made to install dependencies
-    create_command.subprocess.run.assert_not_called()
+    create_command.tools[myapp].app_context.run.assert_not_called()
 
 
 def test_app_packages_empty_requires(
@@ -90,7 +98,7 @@ def test_app_packages_empty_requires(
     create_command.install_app_dependencies(myapp)
 
     # No request was made to install dependencies
-    create_command.subprocess.run.assert_not_called()
+    create_command.tools[myapp].app_context.run.assert_not_called()
 
 
 def test_app_packages_valid_requires(
@@ -99,15 +107,59 @@ def test_app_packages_valid_requires(
     app_packages_path,
     app_packages_path_index,
 ):
-    """If an app has an valid list of requirements, pip is invoked."""
+    """If an app has a valid list of requirements, pip is invoked."""
     myapp.requires = ["first", "second==1.2.3", "third>=3.2.1"]
 
     create_command.install_app_dependencies(myapp)
 
     # A request was made to install dependencies
-    create_command.subprocess.run.assert_called_with(
+    create_command.tools[myapp].app_context.run.assert_called_with(
         [
             sys.executable,
+            "-u",
+            "-m",
+            "pip",
+            "install",
+            "--upgrade",
+            "--no-user",
+            f"--target={app_packages_path}",
+            "first",
+            "second==1.2.3",
+            "third>=3.2.1",
+        ],
+        check=True,
+        env={
+            "PYTHONPATH": str(
+                create_command.bundle_path(myapp)
+                / "path"
+                / "to"
+                / "support"
+                / "platform-site"
+            )
+        },
+    )
+
+
+def test_app_packages_valid_requires_no_support_package(
+    create_command,
+    myapp,
+    app_packages_path,
+    app_packages_path_index,
+):
+    """If the template doesn't specify a support package, the cross-platform
+    site isn't specified."""
+    myapp.requires = ["first", "second==1.2.3", "third>=3.2.1"]
+
+    # Override the cache of paths to specify an app packages path, but no support package path
+    create_command._path_index = {myapp: {"app_packages_path": "path/to/app_packages"}}
+
+    create_command.install_app_dependencies(myapp)
+
+    # A request was made to install dependencies
+    create_command.tools[myapp].app_context.run.assert_called_with(
+        [
+            sys.executable,
+            "-u",
             "-m",
             "pip",
             "install",
@@ -128,23 +180,26 @@ def test_app_packages_invalid_requires(
     app_packages_path,
     app_packages_path_index,
 ):
-    """If an app has an valid list of requirements, pip is invoked."""
+    """If an app has a valid list of requirements, pip is invoked."""
     myapp.requires = ["does-not-exist"]
 
     # Unfortunately, no way to tell the difference between "offline" and
     # "your requirements are invalid"; pip returns status code 1 for all
     # failures.
-    create_command.subprocess.run.side_effect = subprocess.CalledProcessError(
-        cmd=["python", "-m", "pip", "..."], returncode=1
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = subprocess.CalledProcessError(
+        cmd=["python", "-u", "-m", "pip", "..."], returncode=1
     )
 
     with pytest.raises(DependencyInstallError):
         create_command.install_app_dependencies(myapp)
 
     # But the request to install was still made
-    create_command.subprocess.run.assert_called_with(
+    create_command.tools[myapp].app_context.run.assert_called_with(
         [
             sys.executable,
+            "-u",
             "-m",
             "pip",
             "install",
@@ -154,6 +209,15 @@ def test_app_packages_invalid_requires(
             "does-not-exist",
         ],
         check=True,
+        env={
+            "PYTHONPATH": str(
+                create_command.bundle_path(myapp)
+                / "path"
+                / "to"
+                / "support"
+                / "platform-site"
+            )
+        },
     )
 
 
@@ -169,17 +233,20 @@ def test_app_packages_offline(
     # Unfortunately, no way to tell the difference between "offline" and
     # "your requirements are invalid"; pip returns status code 1 for all
     # failures.
-    create_command.subprocess.run.side_effect = subprocess.CalledProcessError(
-        cmd=["python", "-m", "pip", "..."], returncode=1
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = subprocess.CalledProcessError(
+        cmd=["python", "-u", "-m", "pip", "..."], returncode=1
     )
 
     with pytest.raises(DependencyInstallError):
         create_command.install_app_dependencies(myapp)
 
     # But the request to install was still made
-    create_command.subprocess.run.assert_called_with(
+    create_command.tools[myapp].app_context.run.assert_called_with(
         [
             sys.executable,
+            "-u",
             "-m",
             "pip",
             "install",
@@ -191,6 +258,15 @@ def test_app_packages_offline(
             "third",
         ],
         check=True,
+        env={
+            "PYTHONPATH": str(
+                create_command.bundle_path(myapp)
+                / "path"
+                / "to"
+                / "support"
+                / "platform-site"
+            )
+        },
     )
 
 
@@ -206,7 +282,9 @@ def test_app_packages_install_dependencies(
     myapp.requires = ["first", "second", "third"]
 
     # The side effect of calling pip is creating installation artefacts
-    create_command.subprocess.run.side_effect = create_installation_artefacts(
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = create_installation_artefacts(
         app_packages_path, myapp.requires
     )
 
@@ -214,9 +292,10 @@ def test_app_packages_install_dependencies(
     create_command.install_app_dependencies(myapp)
 
     # The request to install was made
-    create_command.subprocess.run.assert_called_with(
+    create_command.tools[myapp].app_context.run.assert_called_with(
         [
             sys.executable,
+            "-u",
             "-m",
             "pip",
             "install",
@@ -228,6 +307,15 @@ def test_app_packages_install_dependencies(
             "third",
         ],
         check=True,
+        env={
+            "PYTHONPATH": str(
+                create_command.bundle_path(myapp)
+                / "path"
+                / "to"
+                / "support"
+                / "platform-site"
+            )
+        },
     )
 
     # The new app packages have installation artefacts created
@@ -254,7 +342,9 @@ def test_app_packages_replace_existing_dependencies(
     myapp.requires = ["first", "second", "third"]
 
     # The side effect of calling pip is creating installation artefacts
-    create_command.subprocess.run.side_effect = create_installation_artefacts(
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = create_installation_artefacts(
         app_packages_path, myapp.requires
     )
 
@@ -262,9 +352,10 @@ def test_app_packages_replace_existing_dependencies(
     create_command.install_app_dependencies(myapp)
 
     # The request to install was still made
-    create_command.subprocess.run.assert_called_with(
+    create_command.tools[myapp].app_context.run.assert_called_with(
         [
             sys.executable,
+            "-u",
             "-m",
             "pip",
             "install",
@@ -276,6 +367,15 @@ def test_app_packages_replace_existing_dependencies(
             "third",
         ],
         check=True,
+        env={
+            "PYTHONPATH": str(
+                create_command.bundle_path(myapp)
+                / "path"
+                / "to"
+                / "support"
+                / "platform-site"
+            )
+        },
     )
 
     # The new app packages have installation artefacts created
