@@ -3,12 +3,33 @@ import pytest
 from briefcase.commands import PackageCommand
 from briefcase.commands.base import full_options
 from briefcase.config import AppConfig
+from briefcase.console import Console, Log
+
+
+class DefaultPackageCommand(PackageCommand):
+    # An instance of PackageCommand that inherits the default
+    # behavior of packaging format handling. Define an output_format
+    # to satisfy the requirements of that interface.
+    output_format = "default"
+
+    # Two methods that are required by the interface, but are not needed
+    # for these tests.
+    def binary_path(self, app):
+        return NotImplementedError()
+
+    def distribution_path(self, app, packaging_format):
+        return NotImplementedError()
+
+
+@pytest.fixture
+def default_package_command(tmp_path):
+    return DefaultPackageCommand(base_path=tmp_path, logger=Log(), console=Console())
 
 
 class DummyPackageCommand(PackageCommand):
     """A dummy package command that doesn't actually do anything.
 
-    It only serves to track which actions would be performend.
+    It only serves to track which actions would be performed.
     """
 
     platform = "tester"
@@ -24,7 +45,9 @@ class DummyPackageCommand(PackageCommand):
         return "pkg"
 
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, apps=[], **kwargs)
+        kwargs.setdefault("logger", Log())
+        kwargs.setdefault("console", Console())
+        super().__init__(*args, apps={}, **kwargs)
 
         self.actions = []
 
@@ -41,6 +64,10 @@ class DummyPackageCommand(PackageCommand):
         super().verify_tools()
         self.actions.append(("verify",))
 
+    def verify_app_tools(self, app):
+        super().verify_app_tools(app=app)
+        self.actions.append(("verify-app-tools", app.app_name))
+
     def package_app(self, app, **kwargs):
         self.actions.append(("package", app.app_name, kwargs))
         return full_options({"package_state": app.app_name}, kwargs)
