@@ -31,6 +31,40 @@ def test_no_args_package_one_app(package_command, first_app):
     ]
 
 
+def test_package_one_explicit_app(package_command, first_app, second_app):
+    """If one app is named explicitly, package that app."""
+    # Add a single app
+    package_command.apps = {
+        "first": first_app,
+        "second": second_app,
+    }
+
+    # Configure no command line arguments
+    options = package_command.parse_options([])
+
+    # Run the build command on a specific app
+    package_command(first_app, **options)
+
+    # The right sequence of things will be done
+    assert package_command.actions == [
+        # Tools are verified
+        ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
+        # Package the first app
+        (
+            "package",
+            "first",
+            {
+                "packaging_format": "pkg",
+                "adhoc_sign": False,
+                "identity": None,
+                "sign_app": True,
+            },
+        ),
+    ]
+
+
 def test_no_args_package_two_app(package_command, first_app, second_app):
     """If there are multiple apps, publish all of them."""
     # Add two apps
@@ -88,7 +122,7 @@ def test_no_sign_package_one_app(package_command, first_app):
         "first": first_app,
     }
 
-    # Configure no command line options
+    # Configure a no-sign option
     options = package_command.parse_options(["--no-sign"])
 
     # Run the run command
@@ -122,7 +156,7 @@ def test_identity_arg_package_one_app(package_command, first_app):
         "first": first_app,
     }
 
-    # Configure no command line options
+    # Configure an identity option
     options = package_command.parse_options(["--identity", "test"])
 
     # Run the run command
@@ -156,7 +190,7 @@ def test_adhoc_sign_package_one_app(package_command, first_app):
         "first": first_app,
     }
 
-    # Configure no command line options
+    # Configure an adhoc signing option
     options = package_command.parse_options(["--adhoc"])
 
     # Run the run command
@@ -191,7 +225,7 @@ def test_no_sign_args_package_two_app(package_command, first_app, second_app):
         "second": second_app,
     }
 
-    # Configure no command line options
+    # Configure a no-sign option
     options = package_command.parse_options(["--no-sign"])
 
     # Run the run command
@@ -293,7 +327,7 @@ def test_identity_sign_args_package_two_app(package_command, first_app, second_a
         "second": second_app,
     }
 
-    # Configure no command line options
+    # Configure an identity option
     options = package_command.parse_options(["--identity", "test"])
 
     # Run the run command
@@ -367,6 +401,61 @@ def test_package_alternate_format(package_command, first_app):
     ]
 
 
+def test_create_before_package(package_command, first_app_config):
+    """If the app hasn't been created, package creates the app first."""
+    # Add a single app
+    package_command.apps = {
+        "first": first_app_config,
+    }
+
+    # Configure no command line options
+    options = package_command.parse_options([])
+
+    # Run the run command
+    package_command(**options)
+
+    # The right sequence of things will be done
+    assert package_command.actions == [
+        # Tools are verified
+        ("verify",),
+        # Create and then build the first app
+        (
+            "create",
+            "first",
+            {
+                "adhoc_sign": False,
+                "identity": None,
+                "sign_app": True,
+            },
+        ),
+        (
+            "build",
+            "first",
+            {
+                "adhoc_sign": False,
+                "create_state": "first",
+                "identity": None,
+                "sign_app": True,
+            },
+        ),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
+        # Package the first app
+        (
+            "package",
+            "first",
+            {
+                "packaging_format": "pkg",
+                "adhoc_sign": False,
+                "identity": None,
+                "sign_app": True,
+                "create_state": "first",
+                "build_state": "first",
+            },
+        ),
+    ]
+
+
 def test_update_package_one_app(package_command, first_app):
     """If there is one app, and a -u argument, package updates the app."""
     # Add a single app
@@ -374,7 +463,7 @@ def test_update_package_one_app(package_command, first_app):
         "first": first_app,
     }
 
-    # Configure no command line options
+    # Configure an update option
     options = package_command.parse_options(["-u"])
 
     # Run the run command
@@ -430,7 +519,7 @@ def test_update_package_two_app(package_command, first_app, second_app):
         "second": second_app,
     }
 
-    # Configure no command line options
+    # Configure an update option
     options = package_command.parse_options(["--update"])
 
     # Run the package command
@@ -520,3 +609,47 @@ def test_update_package_two_app(package_command, first_app, second_app):
             },
         ),
     ]
+
+
+def test_build_before_package(package_command, first_app_unbuilt):
+    """If the an app hasn't been built, it is built before packaging."""
+    # Add a single app
+    package_command.apps = {
+        "first": first_app_unbuilt,
+    }
+
+    # Configure no commmand line options
+    options = package_command.parse_options([])
+
+    # Run the run command
+    package_command(**options)
+
+    # The right sequence of things will be done
+    assert package_command.actions == [
+        # Tools are verified
+        ("verify",),
+        # Build the first app
+        (
+            "build",
+            "first",
+            {
+                "adhoc_sign": False,
+                "identity": None,
+                "sign_app": True,
+            },
+        ),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
+        # Package the first app
+        (
+            "package",
+            "first",
+            {
+                "packaging_format": "pkg",
+                "adhoc_sign": False,
+                "identity": None,
+                "sign_app": True,
+                "build_state": "first",
+            },
+        ),
+    ]
