@@ -2,19 +2,19 @@ from briefcase.console import Console
 
 
 def test_default_constructor():
-    "A console is enabled by default"
+    """A console is enabled by default."""
     console = Console()
     assert console.enabled
 
 
 def test_constructor_with_enabled_false():
-    "A console can be constructed in a disabled state"
+    """A console can be constructed in a disabled state."""
     console = Console(enabled=False)
     assert not console.enabled
 
 
 def test_enable(disabled_console):
-    "A disabled console can be enabled"
+    """A disabled console can be enabled."""
     assert not disabled_console.enabled
 
     disabled_console.enabled = True
@@ -23,7 +23,7 @@ def test_enable(disabled_console):
 
 
 def test_disable():
-    "A disabled console can be enabled"
+    """A disabled console can be enabled."""
     console = Console()
 
     assert console.enabled
