@@ -1,3 +1,4 @@
+from subprocess import CalledProcessError
 from unittest.mock import MagicMock
 
 import pytest
@@ -6,10 +7,10 @@ from briefcase.exceptions import BriefcaseCommandError, InvalidDeviceError
 from briefcase.integrations.android_sdk import ADB
 
 
-def test_start_app_launches_app(mock_sdk, capsys):
+def test_start_app_launches_app(mock_tools, capsys):
     """Invoking `start_app()` calls `run()` with the appropriate parameters."""
     # Mock out the run command on an adb instance
-    adb = ADB(mock_sdk, "exampleDevice")
+    adb = ADB(mock_tools, "exampleDevice")
     adb.run = MagicMock(return_value="example normal adb output")
 
     # Invoke start_app
@@ -32,11 +33,11 @@ def test_start_app_launches_app(mock_sdk, capsys):
     assert "normal adb output" not in capsys.readouterr()
 
 
-def test_missing_activity(mock_sdk):
+def test_missing_activity(mock_tools):
     """If the activity doesn't exist, the error is caught."""
     # Use real `adb` output from launching an activity that does not exist.
     # Mock out the run command on an adb instance
-    adb = ADB(mock_sdk, "exampleDevice")
+    adb = ADB(mock_tools, "exampleDevice")
     adb.run = MagicMock(
         return_value="""\
 Starting: Intent { act=android.intent.action.MAIN cat=[android.intent.category.\
@@ -53,12 +54,24 @@ MainActivity} does not exist.
     assert "Activity class not found" in str(exc_info.value)
 
 
-def test_invalid_device(mock_sdk):
+def test_invalid_device(mock_tools):
     """If the device doesn't exist, the error is caught."""
     # Use real `adb` output from launching an activity that does not exist.
     # Mock out the run command on an adb instance
-    adb = ADB(mock_sdk, "exampleDevice")
+    adb = ADB(mock_tools, "exampleDevice")
     adb.run = MagicMock(side_effect=InvalidDeviceError("device", "exampleDevice"))
 
     with pytest.raises(InvalidDeviceError):
         adb.start_app("com.example.sample.package", "com.example.sample.activity")
+
+
+def test_unable_to_start(mock_tools):
+    """If the adb calls for other reasons, the error is caught."""
+    adb = ADB(mock_tools, "exampleDevice")
+    adb.run = MagicMock(side_effect=CalledProcessError(cmd=["adb"], returncode=1))
+
+    with pytest.raises(
+        BriefcaseCommandError,
+        match=r"Unable to start com.example.sample.package/com.example.sample.activity on exampleDevice",
+    ):
+        adb.start_app("com.example.sample.package", "com.example.sample.activity")
