@@ -14,7 +14,7 @@ def test_build(flatpak, tmp_path):
     )
 
     # The expected call was made
-    flatpak.subprocess.run.assert_called_once_with(
+    flatpak.tools.subprocess.run.assert_called_once_with(
         [
             "flatpak-builder",
             "--force-clean",
@@ -31,12 +31,14 @@ def test_build(flatpak, tmp_path):
 
     # The marker file was created, and was made executable
     assert (tmp_path / "com.example.my-app").exists()
-    flatpak.os.chmod.assert_called_once_with(tmp_path / "com.example.my-app", 0o755)
+    flatpak.tools.os.chmod.assert_called_once_with(
+        tmp_path / "com.example.my-app", 0o755
+    )
 
 
 def test_build_fail(flatpak, tmp_path):
     """If the build fails, an error is raised."""
-    flatpak.subprocess.run.side_effect = subprocess.CalledProcessError(
+    flatpak.tools.subprocess.run.side_effect = subprocess.CalledProcessError(
         cmd="flatpak-builder", returncode=1
     )
 
