@@ -4,8 +4,6 @@ from unittest.mock import ANY
 
 import pytest
 
-from briefcase.console import Log
-
 from .conftest import CREATE_NEW_PROCESS_GROUP, CREATE_NO_WINDOW
 
 
@@ -13,7 +11,7 @@ from .conftest import CREATE_NEW_PROCESS_GROUP, CREATE_NO_WINDOW
 def test_call(mock_sub, capsys, platform):
     """A simple call will be invoked."""
 
-    mock_sub.command.host_os = platform
+    mock_sub.tools.host_os = platform
     mock_sub.Popen(["hello", "world"])
 
     mock_sub._subprocess.Popen.assert_called_with(
@@ -38,7 +36,7 @@ def test_call_with_arg(mock_sub, capsys):
 
 
 def test_call_with_path_arg(mock_sub, capsys, tmp_path):
-    """Path-based arguments are converted to strings andpassed in as-is."""
+    """Path-based arguments are converted to strings and passed in as-is."""
 
     mock_sub.Popen(["hello", tmp_path / "location"], cwd=tmp_path / "cwd")
 
@@ -70,12 +68,16 @@ def test_call_with_path_arg(mock_sub, capsys, tmp_path):
     ],
 )
 def test_call_with_start_new_session(
-    mock_sub, capsys, platform, start_new_session, popen_kwargs
+    mock_sub,
+    capsys,
+    platform,
+    start_new_session,
+    popen_kwargs,
 ):
     """start_new_session is passed thru on Linux and macOS but converted for
     Windows."""
 
-    mock_sub.command.host_os = platform
+    mock_sub.tools.host_os = platform
     mock_sub.Popen(["hello", "world"], start_new_session=start_new_session)
 
     if platform == "Windows":
@@ -106,12 +108,15 @@ def test_call_with_start_new_session(
     ],
 )
 def test_call_windows_with_start_new_session_and_creationflags(
-    mock_sub, capsys, creationflags, final_creationflags
+    mock_sub,
+    capsys,
+    creationflags,
+    final_creationflags,
 ):
     """creationflags used to simulate start_new_session=True should be merged
     with any existing flags."""
 
-    mock_sub.command.host_os = "Windows"
+    mock_sub.tools.host_os = "Windows"
 
     # use commented test below when merging creationflags is allowed
     with pytest.raises(
@@ -124,7 +129,7 @@ def test_call_windows_with_start_new_session_and_creationflags(
 
 def test_debug_call(mock_sub, capsys):
     """If verbosity is turned up, there is output."""
-    mock_sub.command.logger = Log(verbosity=2)
+    mock_sub.tools.logger.verbosity = 2
 
     mock_sub.Popen(["hello", "world"])
 
@@ -144,12 +149,12 @@ def test_debug_call(mock_sub, capsys):
 
 def test_debug_call_with_env(mock_sub, capsys, tmp_path):
     """If verbosity is turned up, and injected env vars are included output."""
-    mock_sub.command.logger = Log(verbosity=2)
+    mock_sub.tools.logger.verbosity = 2
 
     env = {"NewVar": "NewVarValue"}
     mock_sub.Popen(["hello", "world"], env=env, cwd=tmp_path / "cwd")
 
-    merged_env = mock_sub.command.os.environ.copy()
+    merged_env = mock_sub.tools.os.environ.copy()
     merged_env.update(env)
 
     mock_sub._subprocess.Popen.assert_called_with(
