@@ -5,8 +5,6 @@ from unittest.mock import ANY
 
 import pytest
 
-from briefcase.console import Log
-
 
 @pytest.fixture
 def mock_sub(mock_sub, popen_process):
@@ -18,7 +16,7 @@ def mock_sub(mock_sub, popen_process):
 def test_call(mock_sub, capsys):
     """A simple call will be invoked."""
 
-    with mock_sub.command.input.wait_bar():
+    with mock_sub.tools.input.wait_bar():
         mock_sub.run(["hello", "world"])
 
     mock_sub._subprocess.Popen.assert_called_with(
@@ -29,14 +27,22 @@ def test_call(mock_sub, capsys):
         text=True,
         encoding=ANY,
     )
-    expected_output = "output line 1\n" "\n" "output line 3\n" "\n"
+
+    # fmt: off
+    expected_output = (
+        "output line 1\n"
+        "\n"
+        "output line 3\n"
+        "\n"
+    )
+    # fmt: on
     assert capsys.readouterr().out == expected_output
 
 
 def test_call_with_arg(mock_sub, capsys):
     """Any extra keyword arguments are passed through as-is."""
 
-    with mock_sub.command.input.wait_bar():
+    with mock_sub.tools.input.wait_bar():
         mock_sub.run(["hello", "world"], universal_newlines=True)
 
     mock_sub._subprocess.Popen.assert_called_with(
@@ -47,15 +53,22 @@ def test_call_with_arg(mock_sub, capsys):
         universal_newlines=True,
         encoding=ANY,
     )
-    expected_output = "output line 1\n" "\n" "output line 3\n" "\n"
+    # fmt: off
+    expected_output = (
+        "output line 1\n"
+        "\n"
+        "output line 3\n"
+        "\n"
+    )
+    # fmt: on
     assert capsys.readouterr().out == expected_output
 
 
 def test_debug_call(mock_sub, capsys):
     """If verbosity is turned up, there is debug output."""
-    mock_sub.command.logger = Log(verbosity=2)
+    mock_sub.tools.logger.verbosity = 2
 
-    with mock_sub.command.input.wait_bar():
+    with mock_sub.tools.input.wait_bar():
         mock_sub.run(["hello", "world"])
 
     mock_sub._subprocess.Popen.assert_called_with(
@@ -84,13 +97,13 @@ def test_debug_call(mock_sub, capsys):
 def test_debug_call_with_env(mock_sub, capsys, tmp_path):
     """If verbosity is turned up, injected env vars are included in debug
     output."""
-    mock_sub.command.logger = Log(verbosity=2)
+    mock_sub.tools.logger.verbosity = 2
 
     env = {"NewVar": "NewVarValue"}
-    with mock_sub.command.input.wait_bar():
+    with mock_sub.tools.input.wait_bar():
         mock_sub.run(["hello", "world"], env=env, cwd=tmp_path / "cwd")
 
-    merged_env = mock_sub.command.os.environ.copy()
+    merged_env = mock_sub.tools.os.environ.copy()
     merged_env.update(env)
 
     mock_sub._subprocess.Popen.assert_called_with(
@@ -137,7 +150,7 @@ def test_debug_call_with_env(mock_sub, capsys, tmp_path):
 def test_text_eq_true_default_overriding(mock_sub, in_kwargs, kwargs):
     """if text or universal_newlines is explicitly provided, those should
     override text=true default."""
-    with mock_sub.command.input.wait_bar():
+    with mock_sub.tools.input.wait_bar():
         mock_sub.run(["hello", "world"], **in_kwargs)
     mock_sub._subprocess.Popen.assert_called_with(
         ["hello", "world"],
@@ -152,7 +165,7 @@ def test_stderr_is_redirected(mock_sub, popen_process, capsys):
     stderr_output = "stderr output\nline 2"
     popen_process.stderr.read.return_value = stderr_output
 
-    with mock_sub.command.input.wait_bar():
+    with mock_sub.tools.input.wait_bar():
         run_result = mock_sub.run(["hello", "world"], stderr=subprocess.PIPE)
 
     mock_sub._subprocess.Popen.assert_called_with(
@@ -164,7 +177,14 @@ def test_stderr_is_redirected(mock_sub, popen_process, capsys):
         encoding=ANY,
     )
 
-    expected_output = "output line 1\n" "\n" "output line 3\n" "\n"
+    # fmt: off
+    expected_output = (
+        "output line 1\n"
+        "\n"
+        "output line 3\n"
+        "\n"
+    )
+    # fmt: on
     assert capsys.readouterr().out == expected_output
     assert run_result.stderr == stderr_output
 
@@ -173,7 +193,7 @@ def test_stderr_dev_null(mock_sub, popen_process, capsys):
     """When stderr is discarded, it should be None in the result."""
     popen_process.stderr = None
 
-    with mock_sub.command.input.wait_bar():
+    with mock_sub.tools.input.wait_bar():
         run_result = mock_sub.run(["hello", "world"], stderr=subprocess.DEVNULL)
 
     mock_sub._subprocess.Popen.assert_called_with(
@@ -185,7 +205,14 @@ def test_stderr_dev_null(mock_sub, popen_process, capsys):
         encoding=ANY,
     )
 
-    expected_output = "output line 1\n" "\n" "output line 3\n" "\n"
+    # fmt: off
+    expected_output = (
+        "output line 1\n"
+        "\n"
+        "output line 3\n"
+        "\n"
+    )
+    # fmt: on
     assert capsys.readouterr().out == expected_output
     assert run_result.stderr is None
 
@@ -197,10 +224,17 @@ def test_calledprocesserror(mock_sub, popen_process, capsys):
     popen_process.stderr.read.return_value = stderr_output
 
     with pytest.raises(subprocess.CalledProcessError) as exc:
-        with mock_sub.command.input.wait_bar():
+        with mock_sub.tools.input.wait_bar():
             mock_sub.run(["hello", "world"], check=True, stderr=subprocess.PIPE)
 
-    expected_output = "output line 1\n" "\n" "output line 3\n" "\n"
+    # fmt: off
+    expected_output = (
+        "output line 1\n"
+        "\n"
+        "output line 3\n"
+        "\n"
+    )
+    # fmt: on
     assert capsys.readouterr().out == expected_output
     assert exc.value.returncode == -3
     assert exc.value.cmd == ["hello", "world"]
@@ -210,10 +244,10 @@ def test_calledprocesserror(mock_sub, popen_process, capsys):
 def test_invalid_invocations(mock_sub):
     """Ensure run cannot be used in a Wait Bar with invalid arguments."""
     with pytest.raises(AssertionError):
-        with mock_sub.command.input.wait_bar():
+        with mock_sub.tools.input.wait_bar():
             mock_sub.run(["hello", "world"], stdout=subprocess.PIPE)
 
     for invalid_arg in ("timeout", "input"):
         with pytest.raises(AssertionError):
-            with mock_sub.command.input.wait_bar():
+            with mock_sub.tools.input.wait_bar():
                 mock_sub.run(["hello", "world"], **{invalid_arg: "value"})
