@@ -11,6 +11,7 @@ process_list_one_proc = [
         info=dict(cmdline=["/bin/cmd.sh", "--input", "data"], create_time=20, pid=100)
     )
 ]
+
 process_list_two_procs_diff_cmd = [
     Process(
         info=dict(
@@ -23,6 +24,7 @@ process_list_two_procs_diff_cmd = [
         )
     ),
 ]
+
 process_list_two_procs_same_cmd = [
     Process(
         info=dict(cmdline=["/bin/cmd.sh", "--input", "data"], create_time=20, pid=100)
@@ -114,3 +116,17 @@ def test_get_process_id_by_command_w_command(
     found_pid = get_process_id_by_command(command=command, logger=Log())
     assert found_pid == expected_pid
     assert capsys.readouterr().out == expected_stdout
+
+
+def test_get_process_id_no_logging(monkeypatch, capsys):
+    """If no logger is provided, warnings about ambiguous matches aren't
+    printed."""
+    monkeypatch.setattr(
+        "psutil.process_iter",
+        lambda attrs: process_list_two_procs_same_cmd,
+    )
+    found_pid = get_process_id_by_command(
+        command_list=["/bin/cmd.sh", "--input", "data"]
+    )
+    assert found_pid == 100
+    assert capsys.readouterr().out == ""
