@@ -9,9 +9,10 @@ def first_app_config():
         app_name="first-app",
         project_name="First Project",
         formal_name="First App",
+        author="Megacorp",
         bundle="com.example",
         version="0.0.1",
-        description="The first simple app",
+        description="The first simple app \\ demonstration",
         sources=["src/first_app"],
     )
 
@@ -22,6 +23,7 @@ def uppercase_app_config():
         app_name="First-App",
         project_name="First Project",
         formal_name="First App",
+        author="Megacorp",
         bundle="com.example",
         version="0.0.1",
         description="The first simple app",
