@@ -10,32 +10,59 @@ from briefcase.integrations.xcode import DeviceState
 from briefcase.platforms.iOS.xcode import iOSXcodeRunCommand
 
 
-def test_run_app_simulator_booted(first_app_config, tmp_path):
-    """An iOS App can be started when the simulator is already booted."""
-    command = iOSXcodeRunCommand(
+@pytest.fixture
+def run_command(tmp_path):
+    return iOSXcodeRunCommand(
         logger=Log(),
         console=Console(),
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
 
+
+def test_run_multiple_devices_input_disabled(run_command, first_app_config):
+    """If input is disabled, but there are multiple devices, an error is
+    raised."""
+    # Multiple devices are available
+    run_command.get_simulators = mock.MagicMock(
+        return_value={
+            "iOS 13.2": {
+                "C9A005C8-9468-47C5-8376-68A6E3408209": "iPhone 8",
+                "2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D": "iPhone 11",
+                "EEEBA06C-81F9-407C-885A-2261306DB2BE": "iPhone 11 Pro Max",
+            }
+        }
+    )
+
+    # Disable console input.
+    run_command.tools.input.enabled = False
+
+    with pytest.raises(
+        BriefcaseCommandError,
+        match=r"Input has been disabled; can't select a device to target.",
+    ):
+        run_command.run_app(first_app_config)
+
+
+def test_run_app_simulator_booted(run_command, first_app_config, tmp_path):
+    """An iOS App can be started when the simulator is already booted."""
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is already booted
-    command.get_device_state = mock.MagicMock(return_value=DeviceState.BOOTED)
+    run_command.get_device_state = mock.MagicMock(return_value=DeviceState.BOOTED)
 
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
     log_stream_process = mock.MagicMock(spec_set=subprocess.Popen)
-    command.tools.subprocess.Popen.return_value = log_stream_process
+    run_command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
-    command.run_app(first_app_config)
+    run_command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Open the simulator
             mock.call(
@@ -92,7 +119,7 @@ def test_run_app_simulator_booted(first_app_config, tmp_path):
         ]
     )
     # The log is being tailed; no process cleanup is triggered
-    command.tools.subprocess.Popen.assert_called_with(
+    run_command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -111,40 +138,33 @@ def test_run_app_simulator_booted(first_app_config, tmp_path):
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.tools.subprocess.stream_output.assert_called_with(
+    run_command.tools.subprocess.stream_output.assert_called_with(
         "log stream", log_stream_process
     )
-    command.tools.subprocess.cleanup.assert_called_with(
+    run_command.tools.subprocess.cleanup.assert_called_with(
         "log stream", log_stream_process
     )
 
 
-def test_run_app_simulator_shut_down(first_app_config, tmp_path):
+def test_run_app_simulator_shut_down(run_command, first_app_config, tmp_path):
     """An iOS App can be started when the simulator is shut down."""
-    command = iOSXcodeRunCommand(
-        logger=Log(),
-        console=Console(),
-        base_path=tmp_path / "base_path",
-        data_path=tmp_path / "briefcase",
-    )
-
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is shut down
-    command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
+    run_command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
     log_stream_process = mock.MagicMock(spec_set=subprocess.Popen)
-    command.tools.subprocess.Popen.return_value = log_stream_process
+    run_command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
-    command.run_app(first_app_config)
+    run_command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -206,7 +226,7 @@ def test_run_app_simulator_shut_down(first_app_config, tmp_path):
         ]
     )
     # The log is being tailed; no process cleanup is triggered
-    command.tools.subprocess.Popen.assert_called_with(
+    run_command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -225,32 +245,25 @@ def test_run_app_simulator_shut_down(first_app_config, tmp_path):
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.tools.subprocess.stream_output.assert_called_with(
+    run_command.tools.subprocess.stream_output.assert_called_with(
         "log stream", log_stream_process
     )
-    command.tools.subprocess.cleanup.assert_called_with(
+    run_command.tools.subprocess.cleanup.assert_called_with(
         "log stream", log_stream_process
     )
 
 
-def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
+def test_run_app_simulator_shutting_down(run_command, first_app_config, tmp_path):
     """An iOS App can be started when the simulator is shutting down."""
-    command = iOSXcodeRunCommand(
-        logger=Log(),
-        console=Console(),
-        base_path=tmp_path / "base_path",
-        data_path=tmp_path / "briefcase",
-    )
-
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is shutting down. This will be returned a couple of times,
     # as the simulator will take a few seconds before it is fully shut down.
     # There will be a sleep between each call, so we need to mock sleep as well.
-    command.get_device_state = mock.MagicMock(
+    run_command.get_device_state = mock.MagicMock(
         side_effect=[
             DeviceState.SHUTTING_DOWN,
             DeviceState.SHUTTING_DOWN,
@@ -259,19 +272,19 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
         ]
     )
 
-    command.sleep = mock.MagicMock()
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.sleep = mock.MagicMock()
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
     log_stream_process = mock.MagicMock(spec_set=subprocess.Popen)
-    command.tools.subprocess.Popen.return_value = log_stream_process
+    run_command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
-    command.run_app(first_app_config)
+    run_command.run_app(first_app_config)
 
     # We should have slept 4 times
-    assert command.sleep.call_count == 4
+    assert run_command.sleep.call_count == 4
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -333,7 +346,7 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
         ]
     )
     # The log is being tailed; no process cleanup has occurred
-    command.tools.subprocess.Popen.assert_called_with(
+    run_command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -352,42 +365,35 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.tools.subprocess.stream_output.assert_called_with(
+    run_command.tools.subprocess.stream_output.assert_called_with(
         "log stream", log_stream_process
     )
-    command.tools.subprocess.cleanup.assert_called_with(
+    run_command.tools.subprocess.cleanup.assert_called_with(
         "log stream", log_stream_process
     )
 
 
-def test_run_app_simulator_boot_failure(first_app_config, tmp_path):
+def test_run_app_simulator_boot_failure(run_command, first_app_config):
     """If the simulator fails to boot, raise an error."""
-    command = iOSXcodeRunCommand(
-        logger=Log(),
-        console=Console(),
-        base_path=tmp_path / "base_path",
-        data_path=tmp_path / "briefcase",
-    )
-
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is shut down
-    command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
+    run_command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
-    command.tools.subprocess.run.side_effect = subprocess.CalledProcessError(
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.tools.subprocess.run.side_effect = subprocess.CalledProcessError(
         cmd=["xcrun", "simclt", "boot", "..."], returncode=1
     )
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        command.run_app(first_app_config)
+        run_command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -397,31 +403,24 @@ def test_run_app_simulator_boot_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.tools.subprocess.Popen.assert_not_called()
-    command.tools.subprocess.stream_output.assert_not_called()
-    command.tools.subprocess.cleanup.assert_not_called()
+    run_command.tools.subprocess.Popen.assert_not_called()
+    run_command.tools.subprocess.stream_output.assert_not_called()
+    run_command.tools.subprocess.cleanup.assert_not_called()
 
 
-def test_run_app_simulator_open_failure(first_app_config, tmp_path):
+def test_run_app_simulator_open_failure(run_command, first_app_config):
     """If the simulator can't be opened, raise an error."""
-    command = iOSXcodeRunCommand(
-        logger=Log(),
-        console=Console(),
-        base_path=tmp_path / "base_path",
-        data_path=tmp_path / "briefcase",
-    )
-
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is shut down
-    command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
+    run_command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot succeeds, but open fails.
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
-    command.tools.subprocess.run.side_effect = [
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.tools.subprocess.run.side_effect = [
         0,
         subprocess.CalledProcessError(
             cmd=["open", "-a", "Simulator", "..."],
@@ -431,10 +430,10 @@ def test_run_app_simulator_open_failure(first_app_config, tmp_path):
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        command.run_app(first_app_config)
+        run_command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -456,31 +455,24 @@ def test_run_app_simulator_open_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.tools.subprocess.Popen.assert_not_called()
-    command.tools.subprocess.stream_output.assert_not_called()
-    command.tools.subprocess.cleanup.assert_not_called()
+    run_command.tools.subprocess.Popen.assert_not_called()
+    run_command.tools.subprocess.stream_output.assert_not_called()
+    run_command.tools.subprocess.cleanup.assert_not_called()
 
 
-def test_run_app_simulator_uninstall_failure(first_app_config, tmp_path):
+def test_run_app_simulator_uninstall_failure(run_command, first_app_config):
     """If the old app can't be uninstalled, raise an error."""
-    command = iOSXcodeRunCommand(
-        logger=Log(),
-        console=Console(),
-        base_path=tmp_path / "base_path",
-        data_path=tmp_path / "briefcase",
-    )
-
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is shut down
-    command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
+    run_command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot and open simulator succeed, but uninstall fails.
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
-    command.tools.subprocess.run.side_effect = [
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.tools.subprocess.run.side_effect = [
         0,
         0,
         subprocess.CalledProcessError(
@@ -490,10 +482,10 @@ def test_run_app_simulator_uninstall_failure(first_app_config, tmp_path):
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        command.run_app(first_app_config)
+        run_command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -526,31 +518,24 @@ def test_run_app_simulator_uninstall_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.tools.subprocess.Popen.assert_not_called()
-    command.tools.subprocess.stream_output.assert_not_called()
-    command.tools.subprocess.cleanup.assert_not_called()
+    run_command.tools.subprocess.Popen.assert_not_called()
+    run_command.tools.subprocess.stream_output.assert_not_called()
+    run_command.tools.subprocess.cleanup.assert_not_called()
 
 
-def test_run_app_simulator_install_failure(first_app_config, tmp_path):
+def test_run_app_simulator_install_failure(run_command, first_app_config, tmp_path):
     """If the app fails to install in the simulator, raise an error."""
-    command = iOSXcodeRunCommand(
-        logger=Log(),
-        console=Console(),
-        base_path=tmp_path / "base_path",
-        data_path=tmp_path / "briefcase",
-    )
-
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is shut down
-    command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
+    run_command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot and open simulator, and uninstall succeed, but install fails.
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
-    command.tools.subprocess.run.side_effect = [
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.tools.subprocess.run.side_effect = [
         0,
         0,
         0,
@@ -561,10 +546,10 @@ def test_run_app_simulator_install_failure(first_app_config, tmp_path):
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        command.run_app(first_app_config)
+        run_command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -615,31 +600,24 @@ def test_run_app_simulator_install_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.tools.subprocess.Popen.assert_not_called()
-    command.tools.subprocess.stream_output.assert_not_called()
-    command.tools.subprocess.cleanup.assert_not_called()
+    run_command.tools.subprocess.Popen.assert_not_called()
+    run_command.tools.subprocess.stream_output.assert_not_called()
+    run_command.tools.subprocess.cleanup.assert_not_called()
 
 
-def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
+def test_run_app_simulator_launch_failure(run_command, first_app_config, tmp_path):
     """If the app fails to launch, raise an error."""
-    command = iOSXcodeRunCommand(
-        logger=Log(),
-        console=Console(),
-        base_path=tmp_path / "base_path",
-        data_path=tmp_path / "briefcase",
-    )
-
     # A valid target device will be selected.
-    command.select_target_device = mock.MagicMock(
+    run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
     )
 
     # Simulator is shut down
-    command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
+    run_command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot and open simulator, uninstall and install succeed, but launch fails.
-    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
-    command.tools.subprocess.run.side_effect = [
+    run_command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    run_command.tools.subprocess.run.side_effect = [
         0,
         0,
         0,
@@ -649,14 +627,14 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
         ),
     ]
     log_stream_process = mock.MagicMock()
-    command.tools.subprocess.Popen.return_value = log_stream_process
+    run_command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        command.run_app(first_app_config)
+        run_command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.tools.subprocess.run.assert_has_calls(
+    run_command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -718,7 +696,7 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
         ]
     )
     # The log stream process will have been started; but will not be tailed
-    command.tools.subprocess.Popen.assert_called_with(
+    run_command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -737,9 +715,9 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.tools.subprocess.stream_output.assert_not_called()
+    run_command.tools.subprocess.stream_output.assert_not_called()
 
     # The log process was cleaned up.
-    command.tools.subprocess.cleanup.assert_called_once_with(
+    run_command.tools.subprocess.cleanup.assert_called_once_with(
         "log stream", log_stream_process
     )
