@@ -1,12 +1,19 @@
 from unittest import mock
 
+from briefcase.console import Console, Log
+from briefcase.integrations.flatpak import Flatpak
 from briefcase.platforms.linux.flatpak import LinuxFlatpakBuildCommand
 
 
 def test_build(first_app_config, tmp_path):
     """A flatpak can be built."""
-    command = LinuxFlatpakBuildCommand(base_path=tmp_path)
-    command.flatpak = mock.MagicMock()
+    command = LinuxFlatpakBuildCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
+    command.tools.flatpak = mock.MagicMock(spec_set=Flatpak)
 
     first_app_config.flatpak_runtime_repo_url = "https://example.com/flatpak/repo"
     first_app_config.flatpak_runtime_repo_alias = "custom-repo"
@@ -18,13 +25,13 @@ def test_build(first_app_config, tmp_path):
     command.build_app(first_app_config)
 
     # Repo is verified
-    command.flatpak.verify_repo.assert_called_once_with(
+    command.tools.flatpak.verify_repo.assert_called_once_with(
         repo_alias="custom-repo",
         url="https://example.com/flatpak/repo",
     )
 
     # Runtimes are verified
-    command.flatpak.verify_runtime.assert_called_once_with(
+    command.tools.flatpak.verify_runtime.assert_called_once_with(
         repo_alias="custom-repo",
         runtime="org.beeware.Platform",
         runtime_version="37.42",
@@ -32,8 +39,8 @@ def test_build(first_app_config, tmp_path):
     )
 
     # The build is invoked
-    command.flatpak.build.assert_called_once_with(
+    command.tools.flatpak.build.assert_called_once_with(
         bundle="com.example",
         app_name="first-app",
-        path=tmp_path / "linux" / "flatpak" / "First App",
+        path=tmp_path / "base_path" / "linux" / "flatpak" / "First App",
     )
