@@ -2,12 +2,18 @@ from unittest import mock
 
 import pytest
 
+from briefcase.console import Console, Log
 from briefcase.platforms.macOS.app import macOSAppBuildCommand
 
 
 @pytest.fixture
 def build_command(tmp_path):
-    command = macOSAppBuildCommand(base_path=tmp_path)
+    command = macOSAppBuildCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     command.select_identity = mock.MagicMock()
     command.sign_app = mock.MagicMock()
@@ -23,7 +29,8 @@ def test_build_app(build_command, first_app_with_binaries):
 
     # A request has been made to sign the app
     build_command.sign_app.assert_called_once_with(
-        app=first_app_with_binaries, identity="-"
+        app=first_app_with_binaries,
+        identity="-",
     )
 
     # No request to select a signing identity was made
